@@ -80,6 +80,11 @@ impl<'env, 'source> Template<'env, 'source> {
     pub(crate) fn blocks(&self) -> &'env BTreeMap<&'source str, Instructions<'source>> {
         &self.compiled.blocks
     }
+
+    /// Returns the initial auto escape setting.
+    pub(crate) fn initial_auto_escape(&self) -> AutoEscape {
+        self.compiled.initial_auto_escape
+    }
 }
 
 /// An abstraction that holds the engine configuration.
@@ -261,7 +266,7 @@ impl<'source> Environment<'source> {
     /// Adds a new test function.
     ///
     /// For details about tests have a look at [`tests`].
-    pub fn add_test<F, V, Rv, Args>(&mut self, name: &'source str, f: F)
+    pub fn add_test<F, V, Args>(&mut self, name: &'source str, f: F)
     where
         V: TryFrom<Value>,
         F: tests::Test<V, Args>,
