@@ -27,7 +27,7 @@
 //!
 //! # Template Usage
 //!
-//! To use MiniJinja one needs to create an [`Environment`] and pupulate it with templates.
+//! To use MiniJinja one needs to create an [`Environment`] and populate it with templates.
 //! Afterwards templates can be loaded and rendered.  To pass data one can pass any serde
 //! serializable value:
 //!
@@ -47,7 +47,7 @@
 //! MiniJinja — like Jinja2 — allows to be used as expression language.  This can be
 //! useful to express logic in configuration files or similar things.  For this
 //! purpose the [`Environment::compile_expression`] method can be used.  It returns
-//! an expression object that can then be evaluate and the result is returned:
+//! an expression object that can then be evaluated, returning the result:
 //!
 //! ```
 //! use std::collections::BTreeMap;
@@ -58,6 +58,24 @@
 //! let result = expr.eval(&()).unwrap();
 //! assert_eq!(result.is_true(), true);
 //! ```
+//!
+//! # Learn more
+//!
+//! - [`syntax`]: documentation of the template engine syntax.
+//! - [`filters`]: for how to write custom filters and list of built-in filters.
+//! - [`tests`]: for how to write custom test functions and list of built-in tests.
+//! - [`value`]: for information about the runtime value object.
+//! - [`Environment`]: the main API entry point.
+//! - [`Template`]: the template object API.
+//!
+//! # Optional Features
+//!
+//! There are some additional features that can be enabled:
+//!
+//! - `memchr`: enables the `memchr` dependency which provides performance improvements
+//!   for the parser.
+//! - `unstable_machinery`: provides access to the internal machinery of the engine.  This
+//!   is a forever unstable API which mainly exists to aid debugging complex issues.
 mod key;
 
 mod ast;
@@ -72,6 +90,7 @@ mod utils;
 mod vm;
 
 pub mod filters;
+pub mod syntax;
 pub mod tests;
 pub mod value;
 
