@@ -411,6 +411,10 @@ impl<'a> Parser<'a> {
                 self.parse_extends()?,
                 self.stream.expand_span(span),
             ))),
+            Token::Ident("include") => Ok(ast::Stmt::Include(Spanned::new(
+                self.parse_include()?,
+                self.stream.expand_span(span),
+            ))),
             Token::Ident("autoescape") => Ok(ast::Stmt::AutoEscape(Spanned::new(
                 self.parse_auto_escape()?,
                 self.stream.expand_span(span),
@@ -511,6 +515,11 @@ impl<'a> Parser<'a> {
         Ok(ast::Extends { name })
     }
 
+    fn parse_include(&mut self) -> Result<ast::Include<'a>, Error> {
+        let name = self.parse_expr()?;
+        Ok(ast::Include { name })
+    }
+
     fn parse_auto_escape(&mut self) -> Result<ast::AutoEscape<'a>, Error> {
         let enabled = self.parse_expr()?;
         expect_token!(self, Token::BlockEnd(..), "end of block")?;
