@@ -36,6 +36,12 @@
 //! let v = u64::try_from(Value::from(42)).unwrap();
 //! ```
 //!
+//! # Value Function Arguments
+//!
+//! [Filters](crate::filters) and (tests)[crate::tests] can take values as arguments
+//! but optionally also rust types directly.  This conversion for function arguments
+//! is performed by the [`ValueArgs`] trait.
+//!
 //! # Memory Management
 //!
 //! Values are immutable objects which are internally reference counted which
@@ -173,13 +179,13 @@ enum Repr {
 impl fmt::Debug for Repr {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            Repr::Undefined => write!(f, ""),
+            Repr::Undefined => write!(f, "Undefined"),
             Repr::Bool(val) => fmt::Debug::fmt(val, f),
             Repr::U64(val) => fmt::Debug::fmt(val, f),
             Repr::I64(val) => fmt::Debug::fmt(val, f),
             Repr::F64(val) => fmt::Debug::fmt(val, f),
             Repr::Char(val) => fmt::Debug::fmt(val, f),
-            Repr::None => write!(f, "none"),
+            Repr::None => write!(f, "None"),
             Repr::Shared(val) => fmt::Debug::fmt(val, f),
         }
     }
@@ -200,7 +206,7 @@ enum Shared {
     // dynamic type also wants to hold on to it without having to inspect
     // into a value object.  It would be nice to be able to store this
     // adjacent to `Shared` but unfortunately a `dyn Trait` needs two
-    // pointers and that incrases the size of the value type for all
+    // pointers and that increases the size of the value type for all
     // uses.
     Dynamic(RcType<dyn DynamicObject>),
 }
